from setuptools import setup

setup(
    name='jcv',
    version='0.0.1',
    description='Computer Vision in Jax',
    long_description='',
    url='https://github.com/netw0rkf10w/jcv',
    author='D.Khue Le-Huu',
    author_email='me@khue.fr',
    packages=[]
)